# Plover Better RTF

[![pypi](https://img.shields.io/pypi/v/plover-better-rtf)](https://pypi.org/project/plover-better-rtf)
![python](https://img.shields.io/pypi/pyversions/plover-better-rtf)
![build](https://github.com/sammdot/plover-better-rtf/workflows/build/badge.svg)

Plover plugin for better RTF dictionary handling. Powered by
[rtfcre](https://github.com/sammdot/rtfcre).

Unfortunately, I can't find a way to override Plover's built-in RTF dictionary
plugin, so for now your RTF dictionaries will have to be named `.rtfcre` if you
want to use this plugin.
